<?php

namespace Lkn\LknWPCrowdfunding\Includes\elementorFields;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingAuthorControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingButtonsControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingDaysControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingDescriptionControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingFundRaisedControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingGoalControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingImage;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingLocationControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingMainContent;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingProgressControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\controls\LknWPCrowdfundingListingTitleControl;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\database\LknWPCrowdfundingListingQuery;
use Lkn\LknWPCrowdfunding\Includes\elementorFields\helpers\LknWPCrowdfundingListingFunctions;

if (! defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class LknWPCrowdfundingListingWidget extends Widget_Base
{
    private $lknwpHelper;

    public function __construct($data = [], $args = null)
    {
        parent::__construct($data, $args);

        $this->lknwpHelper = new LknWPCrowdfundingListingFunctions();
    }

    public function get_name()
    {
        return 'lkn-wp-crowdfunding-extension-listing';
    }

    public function get_title()
    {
        return __('Campaign Listing', 'lkn-wp-crowdfunding-extension');
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }

    public function get_categories()
    {
        return [ 'lkn-wp-crowdfunding-extension' ]; // Ajuste conforme necessário.
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Content', 'lkn-wp-crowdfunding-extension'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        LknWPCrowdfundingListingMainContent::getControl($this);

        $this->end_controls_section();

        /////////////////////////////////////////////////////////////

        LknWPCrowdfundingListingImage::getControl($this);
        LknWPCrowdfundingListingButtonsControl::getControl($this);
        LknWPCrowdfundingListingTitleControl::getControl($this);
        LknWPCrowdfundingListingAuthorControl::getControl($this);
        LknWPCrowdfundingListingDescriptionControl::getControl($this);
        LknWPCrowdfundingListingLocationControl::getControl($this);
        LknWPCrowdfundingListingProgressControl::getControl($this);
        LknWPCrowdfundingListingGoalControl::getControl($this);
        LknWPCrowdfundingListingFundRaisedControl::getControl($this);
        LknWPCrowdfundingListingDaysControl::getControl($this);
    }

    public function render()
    {
        $settings = $this->get_settings_for_display();
        $thumbnail = '';

        $mainBackgroundColor = 'background-color: #FFFFFF;';
        if (!empty($settings['main_background_color'])) {
            $mainBackgroundColor = 'background-color: ' . $settings['main_background_color'] . ';';
        }

        $buttonsSettings = LknWPCrowdfundingListingButtonsControl::getFields($settings);
        $titleSettings = LknWPCrowdfundingListingTitleControl::getFields($settings);
        $authorSettings = LknWPCrowdfundingListingAuthorControl::getFields($settings);
        $descriptionSettings = LknWPCrowdfundingListingDescriptionControl::getFields($settings);
        $locationSettings = LknWPCrowdfundingListingLocationControl::getFields($settings);
        $progressSettings = LknWPCrowdfundingListingProgressControl::getFields($settings);
        $goalSettings = LknWPCrowdfundingListingGoalControl::getFields($settings);
        $fundRaisedSettings = LknWPCrowdfundingListingFundRaisedControl::getFields($settings);
        $daysSettings = LknWPCrowdfundingListingDaysControl::getFields($settings);

        $campaign_query = LknWPCrowdfundingListingQuery::getQuery($settings);

        // Define as campanhas e os dados necessários
        $campaigns = [];

        if ($campaign_query->have_posts()) {
            while ($campaign_query->have_posts()) {
                $campaign_query->the_post();

                $thumbnail_id = get_post_thumbnail_id(get_the_ID());
                if ($thumbnail_id) {
                    $thumbnail = get_the_post_thumbnail(get_the_ID(), $settings['thumbnail_size']);
                    $thumbnail = str_replace('class="', 'class="lknwp-image ', $thumbnail);
                } else {
                    $placeholder_id = get_option('woocommerce_placeholder_image');
                    $thumbnail = wp_get_attachment_image($placeholder_id, $settings['thumbnail_size']);
                    $thumbnail = str_replace('class="', 'class="lknwp-image ', $thumbnail);
                }

                $end_method = get_post_meta(get_the_ID(), 'wpneo_campaign_end_method', true);

                $campaigns[] = [
                    'id'             => get_the_ID(),
                    'title'          => get_the_title(),
                    'permalink'      => get_permalink(),
                    'thumbnail'      => $thumbnail,
                    'excerpt'        => wp_kses(htmlspecialchars_decode(get_the_excerpt()), []),
                    'location'       => $this->lknwpHelper->campaign_location(),
                    'author_name'    => $this->lknwpHelper->get_author_name(),
                    'author_url'     => $this->lknwpHelper->get_author_url(get_the_author_meta('user_login')),
                    'raised_percent' => $this->lknwpHelper->get_raised_percent(get_the_ID()),
                    'funding_goal'   => $this->lknwpHelper->get_total_goal(get_the_ID()),
                    'fund_raised'    => $this->lknwpHelper->get_total_fund(get_the_ID()),
                    'days_remaining' => $this->lknwpHelper->get_date_remaining(get_the_ID()),
                    'end_method'     => $end_method,
                ];
            }
        }

        // Inclui o template e passa os dados
        require LKN_WP_CROWDFUNDING_EXTENSION_DIR . 'Includes/elementorFields/views/LknWPCrowdfundingListingCard.php';

        wp_reset_postdata();
    }

    public static function lknwp_get_settings()
    {
        return $this->get_settings_for_display();
    }
}
