<?php

namespace Lkn\LknWPCrowdfunding\Includes\elementorFields\controls;

use Elementor\Controls_Manager;

class LknWPCrowdfundingListingImage
{
    public static function getControl($input)
    {
        $input->start_controls_section(
            'image_section',
            [
                'label' => __('Image', 'lkn-wp-crowdfunding-extension'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $input->add_control(
            'show_image',
            [
                'label'        => __('Show Image', 'lkn-wp-crowdfunding-extension'),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __('Yes', 'lkn-wp-crowdfunding-extension'),
                'label_off'    => __('No', 'lkn-wp-crowdfunding-extension'),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $input->add_control(
            'image_width',
            [
                'label'      => __('Image Width', 'lkn-wp-crowdfunding-extension'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em'],
                'range'      => [
                    'px' => [
                        'min' => 10,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                    'em' => [
                        'min' => 1,
                        'max' => 50,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 300,
                ],
                'selectors' => [
                    '{{WRAPPER}} .lknwp-image' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_image' => 'yes',
                ],
            ]
        );

        $input->add_control(
            'image_height',
            [
                'label'      => __('Image Height', 'lkn-wp-crowdfunding-extension'),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px', '%', 'em'],
                'range'      => [
                    'px' => [
                        'min' => 10,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                    'em' => [
                        'min' => 1,
                        'max' => 50,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 160,
                ],
                'selectors' => [
                    '{{WRAPPER}} .lknwp-image' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'show_image' => 'yes',
                ],
            ]
        );

        $input->add_control(
            'thumbnail_size',
            [
                'label'   => __('Image Size', 'lkn-wp-crowdfunding-extension'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'thumbnail' => __('Thumbnail', 'lkn-wp-crowdfunding-extension'),
                    'medium'    => __('Medium', 'lkn-wp-crowdfunding-extension'),
                    'large'     => __('Large', 'lkn-wp-crowdfunding-extension'),
                    'full'      => __('Full', 'lkn-wp-crowdfunding-extension'),
                ],
                'default' => 'full',
                'condition' => [
                    'show_image' => 'yes',
                ],
            ]
        );

        $input->end_controls_section();

        return $input;
    }
}
