<?php

namespace Lkn\LknWPCrowdfunding\Includes\elementorFields\controls;

use Elementor\Controls_Manager;

class LknWPCrowdfundingListingMainContent
{
    public static function getControl($input)
    {
        $pages = get_posts([
            'post_type'   => 'page',
            'post_status' => 'publish',
            'numberposts' => -1,
        ]);

        // Formatar as opções para o campo select
        $page_options = ['none' => __('Default', 'lkn-wp-crowdfunding-extension')];
        if (!empty($pages)) {
            foreach ($pages as $page) {
                $page_options[$page->ID] = $page->post_title;
            }
        }

        // Campo para categoria
        $input->add_control(
            'category',
            [
                'label'       => __('Category', 'lkn-wp-crowdfunding-extension'),
                'type'        => Controls_Manager::TEXT,
                'description' => __('Add category slugs separated by commas.', 'lkn-wp-crowdfunding-extension'),
                'placeholder' => __('e.g. technology, health', 'lkn-wp-crowdfunding-extension'),
            ]
        );

        // Campo para número de posts
        $input->add_control(
            'number',
            [
                'label'       => __('Number of Posts per section', 'lkn-wp-crowdfunding-extension'),
                'type'        => Controls_Manager::NUMBER,
                'default'     => 10,
            ]
        );

        // Campo para ordenação
        $input->add_control(
            'order',
            [
                'label'       => __('Order', 'lkn-wp-crowdfunding-extension'),
                'type'        => Controls_Manager::SELECT,
                'options'     => [
                    'ASC'  => __('Ascending', 'lkn-wp-crowdfunding-extension'),
                    'DESC' => __('Descending', 'lkn-wp-crowdfunding-extension'),
                    'RAND' => __('Random', 'lkn-wp-crowdfunding-extension'),
                ],
                'default'     => 'DESC',
            ]
        );

        $input->add_control(
            'divider',
            [
                'type' => Controls_Manager::DIVIDER,
            ]
        );

        $input->add_control(
            'main_background_color',
            [
                'label'     => __('Background Color', 'lkn-wp-crowdfunding-extension'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#FFFFFF',
            ]
        );

        // Campo para Largura - Responsivo
        $input->add_responsive_control(
            'width',
            [
                'label'       => __('Width', 'lkn-wp-crowdfunding-extension'),
                'type'        => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .lknwp-elementor-width' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'size_units'  => ['px'],
                'range'       => [
                    'px' => [
                        'min' => 80,
                        'max' => 1300,
                        'step' => 1,
                    ]
                ],
                'default'     => [
                    'unit' => 'px',
                    'size' => 300,
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 300,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 300,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 300,
                    'unit' => 'px',
                ],
                'description' => __('Minimum width is 240px.', 'lkn-wp-crowdfunding-extension'),
            ]
        );

        // Campo para Altura - Responsivo
        $input->add_responsive_control(
            'height',
            [
                'label'       => __('Height', 'lkn-wp-crowdfunding-extension'),
                'type'        => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .lknwp-elementor-height' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'size_units'  => ['px'],
                'range'       => [
                    'px' => [
                        'min' => 80,
                        'max' => 2000,
                        'step' => 1,
                    ]
                ],
                'default'     => [
                    'unit' => 'px',
                    'size' => 640,
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 600,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 600,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 600,
                    'unit' => 'px',
                ],
                'description' => __('Minimum height is 230px.', 'lkn-wp-crowdfunding-extension'),
            ]
        );

        $input->add_responsive_control(
            'gap',
            [
                'label'       => __('Gap', 'lkn-wp-crowdfunding-extension'),
                'type'        => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .lknwp-elementor-gap' => 'gap: {{SIZE}}{{UNIT}};',
                ],
                'size_units'  => ['px'],
                'range'       => [
                    'px' => [
                        'min' => 5,
                        'max' => 50,
                        'step' => 1,
                    ]
                ],
                'default'     => [
                    'unit' => 'px',
                    'size' => 5,
                ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 5,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 5,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 5,
                    'unit' => 'px',
                ],
                'description' => __('Minimum gap is 5px.', 'lkn-wp-crowdfunding-extension'),
            ]
        );

        $input->add_control(
            'lkn_template_page',
            [
                'label'       => __('Select Template', 'lkn-wp-crowdfunding-extension'),
                'type'        => Controls_Manager::SELECT,
                'options'     => $page_options,
                'default'     => key($page_options), // Primeiro item como padrão
                'description' => __('Select a template to display it.', 'lkn-wp-crowdfunding-extension'),
            ]
        );

        return $input;
    }
}
