<?php
$product_id = get_the_ID(); // Obtém o ID do produto atual

// Obtém o ID do autor do produto
$user_id = get_post_field('post_author', $product_id);

// Verifica se há um usuário logado
if (!$user_id) {
    echo esc_html__('Please log in to view your profile and donation details.', 'lkn-wp-crowdfunding-extension');
    return;
}

// Obter o número de doações do WP Crowdfunding na tabela wp_wc_orders
global $wpdb;

$donation_count = $wpdb->get_var(
    $wpdb->prepare(
        "SELECT COUNT(*) FROM {$wpdb->prefix}wc_orders WHERE customer_id = %d AND status = %s",
        $user_id,
        'wc-completed'
    )
);

if (!$donation_count) {
    $donation_count = 0;
}

// Obter a contagem de campanhas favoritas
$loved_campaign_ids = get_user_meta($user_id, 'loved_campaign_ids', true);
$favorite_count = 0;

if ($loved_campaign_ids) {
    $loved_campaign_ids_array = json_decode($loved_campaign_ids, true);
    if (is_array($loved_campaign_ids_array)) {
        $favorite_count = count($loved_campaign_ids_array);
    }
}

// Obter o nome completo e a imagem de perfil do autor
$user_info = get_userdata($user_id);
$first_name = ucfirst(strtolower($user_info->first_name));
$last_name = ucfirst(strtolower($user_info->last_name));
$full_name = trim($first_name . ' ' . $last_name);
$profile_image = get_avatar($user_id, 128); // Imagem de perfil com tamanho 128x128

// Outras informações do usuário
$email = $user_info->user_email;
$city = ucwords(get_user_meta($user_id, 'billing_city', true));
$state = ucwords(get_user_meta($user_id, 'billing_state', true));
$country = get_user_meta($user_id, 'billing_country', true); // País
$date_format = get_option('date_format', 'F j, Y');
$registration_date = gmdate($date_format, strtotime($user_info->user_registered));

if (\Elementor\Plugin::$instance->editor->is_edit_mode() || is_preview()) {
    $first_name = __('Name', 'lkn-wp-crowdfunding-extension');
    $last_name = __('Lastname', 'lkn-wp-crowdfunding-extension');
    $full_name = __('Name Lastname', 'lkn-wp-crowdfunding-extension');
    $email = __('email@edit.com', 'lkn-wp-crowdfunding-extension');
    $city = __('City', 'lkn-wp-crowdfunding-extension');
    $state = __('State', 'lkn-wp-crowdfunding-extension');
    $country = __('Country', 'lkn-wp-crowdfunding-extension');
    $registration_date = __('Month 01, Year', 'lkn-wp-crowdfunding-extension');
    $donation_count = 1;
    $favorite_count = 0;
}
?>

<div class="lkn-user-profile-container">
    <div class="lkn-user-profile-image">
        <?php echo wp_kses_post($profile_image); // Escapa imagens ou conteúdo HTML seguro?>
    </div>

    <div class="lkn-user-details">
        <div class="lkn-user-name">
            <?php echo esc_html($full_name); ?>
        </div>

        <div class="lkn-campaign-count">
            <?php echo sprintf(
                // translators: Favorite campaign
                esc_html__('%1$d campaign(s) | %2$d favorite campaign(s)', 'lkn-wp-crowdfunding-extension'),
                esc_html($donation_count),
                esc_html($favorite_count)
            ); ?>
        </div>

        <a
            href="#"
            class="lkn-open-bio-modal"
        >
            <?php echo esc_html__('View full biography', 'lkn-wp-crowdfunding-extension'); ?>
        </a>
    </div>
</div>