<?php

namespace Lkn\LknWPCrowdfunding\PublicView;

use Lkn\LknWPCrowdfunding\Includes\LknWPCrowdfundingHelper;

final class LknWPCrowdfundingPublic
{
    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles(): void
    {
        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Lkn_Wp_Crowdfunding_Extension_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Lkn_Wp_Crowdfunding_Extension_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        if (class_exists('Elementor\Plugin') && did_action('elementor/loaded')) {
            wp_enqueue_style($this->plugin_name . "-listing-card", plugin_dir_url(__FILE__) . 'css/LknWPCrowdfundingListingCard.css', array(), $this->version, 'all');

            wp_register_style(
                'lknWpCrowdfundingElementor',
                LKN_WP_CROWDFUNDING_EXTENSION_URL . 'Admin/css/LknWpCrowdfundingExtensionElementor.css',
                array(),
                $this->version,
                'all'
            );

            if (! \Elementor\Plugin::$instance->editor->is_edit_mode()) {
                wp_enqueue_style('lknWpCrowdfundingElementor');
            }
        }
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts(): void
    {
        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Lkn_Wp_Crowdfunding_Extension_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Lkn_Wp_Crowdfunding_Extension_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script('lkn-wp-crowdfunding-public', plugin_dir_url(__FILE__) . 'js/lkn-wp-crowdfunding-extension-public.js', array('jquery'), $this->version, true);

        if (class_exists('Elementor\Plugin') && did_action('elementor/loaded')) {
            wp_register_script(
                'lknwp-wc-listing-public',
                plugin_dir_url(__FILE__) . 'js/LknWPCrowdfundingListing.js',
                array('jquery'),
                $this->version,
                false
            );

            wp_enqueue_script('lknwp-wc-listing-public');

            wp_register_script(
                'lknwp-wc-listing-public-load-more',
                plugin_dir_url(__FILE__) . 'js/LknWPCrowdfundingListingLoadMore.js',
                array('jquery'),
                $this->version,
                false
            );

            wp_enqueue_script('lknwp-wc-listing-public-load-more');

            $settings = LknWPCrowdfundingHelper::get_messages();

            wp_localize_script('lknwp-wc-listing-public-load-more', 'lknwp_settings', $settings);

            wp_enqueue_script(
                'lknwp-wc-payment',
                plugin_dir_url(__FILE__) . 'js/LknWPCrowdfundingPayment.js',
                array('jquery'),
                $this->version,
                false
            );

            wp_localize_script(
                'lknwp-wc-payment',
                'lknWpCrowdfundingParams',
                LknWPCrowdfundingHelper::get_translations()
            );

            $finalization_url = wc_get_checkout_url();

            wp_localize_script(
                'lknwp-wc-payment',
                'lknwpGlobal',
                array(
                    'finalization_url' => $finalization_url
                )
            );

            wp_enqueue_script(
                'lknwp-elevate-zoom',
                LKN_WP_CROWDFUNDING_EXTENSION_URL . 'Admin/js/LknWPLibElevateZoom.min.js',
                array('jquery'),
                $this->version,
                false
            );

            wp_register_script(
                'lknWpCrowdfundingElementor',
                LKN_WP_CROWDFUNDING_EXTENSION_URL . 'Admin/js/LknWpCrowdfundingExtensionElementor.js',
                array('jquery', 'lknwp-elevate-zoom'),
                $this->version,
                false
            );

            wp_localize_script(
                'lknWpCrowdfundingElementor',
                'lknWpCrowdfundingParams',
                LknWPCrowdfundingHelper::get_translations()
            );

            if (! \Elementor\Plugin::$instance->editor->is_edit_mode()) {
                wp_enqueue_script('lknWpCrowdfundingElementor');
            }
        }
    }
}
