<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://https://www.linknacional.com.br/
 * @since             1.0.0
 * @package           Lkn_Wp_Crowdfunding_Extension
 *
 * @wordpress-plugin
 * Plugin Name:       Link Nacional WP Crowdfunding Extension
 * Plugin URI:        https://https://www.linknacional.com.br/wordpress/plugins/
 * Description:       A Link Nacional extension of the WP Crowdfunding plugin
 * Requires Plugins:  wp-crowdfunding
 * Version:           1.6.0
 * Author:            Link Nacional
 * Author URI:        https://https://www.linknacional.com.br//
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       lkn-wp-crowdfunding-extension
 * Domain Path:       /Languages
 */

use Lkn\LknWPCrowdfunding\Includes\LknWPCrowdfunding;
use Lkn\LknWPCrowdfunding\Includes\LknWPCrowdfundingActivator;
use Lkn\LknWPCrowdfunding\Includes\LknWPCrowdfundingDeactivator;

// If this file is called directly, abort.
if (! defined('WPINC')) {
    die;
}

require_once __DIR__ . '/vendor/autoload.php';

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('LKN_WP_CROWDFUNDING_EXTENSION_VERSION', '1.6.0');

if (! defined('LKN_WP_CROWDFUNDING_EXTENSION_MIN_CROWDFUNDING_VERSION')) {
    define('LKN_WP_CROWDFUNDING_EXTENSION_MIN_CROWDFUNDING_VERSION', '2.1.10');
}

if (! defined('LKN_WP_CROWDFUNDING_EXTENSION_FILE')) {
    define('LKN_WP_CROWDFUNDING_EXTENSION_FILE', __DIR__ . '/lkn-wp-crowdfunding-extension.php');
}

if (! defined('LKN_WP_CROWDFUNDING_EXTENSION_DIR')) {
    define('LKN_WP_CROWDFUNDING_EXTENSION_DIR', plugin_dir_path(LKN_WP_CROWDFUNDING_EXTENSION_FILE));
}

if (! defined('LKN_WP_CROWDFUNDING_EXTENSION_URL')) {
    define('LKN_WP_CROWDFUNDING_EXTENSION_URL', plugin_dir_url(LKN_WP_CROWDFUNDING_EXTENSION_FILE));
}

if (! defined('LKN_WP_CROWDFUNDING_EXTENSION_BASENAME')) {
    define('LKN_WP_CROWDFUNDING_EXTENSION_BASENAME', plugin_basename(LKN_WP_CROWDFUNDING_EXTENSION_FILE));
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-lkn-wp-crowdfunding-extension-activator.php
 */
function activate_lkn_wp_crowdfunding_extension(): void
{
    LknWPCrowdfundingActivator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-lkn-wp-crowdfunding-extension-deactivator.php
 */
function deactivate_lkn_wp_crowdfunding_extension(): void
{
    LknWPCrowdfundingDeactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_lkn_wp_crowdfunding_extension');
register_deactivation_hook(__FILE__, 'deactivate_lkn_wp_crowdfunding_extension');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'Includes/LknWPCrowdfunding.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.1
 */
function run_lkn_wp_crowdfunding_extension(): void
{
    $plugin = new LknWPCrowdfunding();
    $plugin->run();
}
run_lkn_wp_crowdfunding_extension();
